plot_map.RdPlot geography shapefiles using geom_sf
plot_map( data, method = "tmap", fill_with, tmap_mode = "view", alpha = 0.5, ... )
| data | An sf object that contains the geometries |
|---|---|
| method | Plotting method. Can be "sf" or "tmap" |
| fill_with | (Optional) The variable from the sf object to fill the polygons. |
| tmap_mode | Map mode if tmap is chosen as the mapping method. |
| alpha | Transparency |
| ... | Other arguments passed on to |
A ggplot or tmap object.