read_licensing.RdRead DHS Licensing Data from the shared Google Drive folder.
read_licensing( table = "provider", version, filetype = "rds", filled = FALSE, GDRIVE_ROOT = Sys.getenv("GDRIVE_ROOT") )
| table | Licensing table to read. Either "provider", or "shift". |
|---|---|
| version | Licensing data version. Either "2021-04" or "2021-02". |
| filetype | Data file type. Either "csv" or "rds". |
| filled | Missing variables filled in using other data sources (like Nware) or imputation. |
| GDRIVE_ROOT | The local path to the folder that contains the MinnCCAccess folder. |
A tibble of Licensing data.