read_nware.RdRead Nware Data from the shared Google Drive folder.
read_nware( table = "characteristics", version, filetype = "rds", GDRIVE_ROOT = Sys.getenv("GDRIVE_ROOT") )
| table | Nware table to read. Either "characteristics", "provider_schedule_daily", "provider_schedule_hourly", "shift", or "age_group_shift". |
|---|---|
| version | Nware version. Either "2021-04" or "2020-10". |
| filetype | Data file type. Either "csv" or "rds". |
| GDRIVE_ROOT | The local path to the folder that contains the MinnCCAccess folder. |
A tibble of Nware data.