read_parentaware.RdRead Parent Aware Data from the shared Google Drive folder.
read_parentaware(filetype = "rds", GDRIVE_ROOT = Sys.getenv("GDRIVE_ROOT"))
| filetype | "rds" or "csv". Defaults to "rds". |
|---|---|
| GDRIVE_ROOT | The local path to the folder that contains the MinnCCAccess folder. |
A tibble