read_pecc.RdRead PECC Grant Data from the shared Google Drive folder.
read_pecc(filetype = "rds", GDRIVE_ROOT = Sys.getenv("GDRIVE_ROOT"))
| filetype | "rds" or "csv" |
|---|---|
| GDRIVE_ROOT | The local path to the folder that contains the MinnCCAccess folder. |
A tibble