read_public.RdRead Public School Enrollment Data from the shared Google Drive folder.
read_public( table = "school", subgroups = FALSE, all_grades = FALSE, filetype = "rds", GDRIVE_ROOT = Sys.getenv("GDRIVE_ROOT") )
| table | "school" or "school-district". Defaults to "school". |
|---|---|
| subgroups | Set TRUE to add demographic (gender, race) and other subgroups. Defaults to FALSE. |
| all_grades | Set TRUE to get grade school enrollments as well as enrollment in early education. Defaults to FALSE. |
| filetype | "rds" or "csv". Defaults to "rds". |
| GDRIVE_ROOT | The local path to the folder that contains the MinnCCAccess folder. |
Minnesota Department of Education
A tibble